"""This package contains example applications included with Lino.

See also :doc:`/tutorials/hello/index` which explains how to try them
out.

Examples with their own documentation entry:

- :mod:`lino_book.projects.belref` ---
  See :ref:`belref`
- :mod:`lino_book.projects.polly`
  See :ref:`polly`

Poorly documented examples at different development states:

.. autosummary::
   :toctree:

   min1
   min2
   max
   dumps
   events
   cms
   crl
   homeworkschool
   igen
   i18n


Examples covered by a tutorial:

- :mod:`lino_book.projects.babel_tutorial` ---
  See :ref:`mldbc_tutorial`

Technical

.. autosummary::
   :toctree:

   docs
   belref
   estref


"""

